PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Util/Util.hpp Source File

PCB Environment 2

Loading...
Searching...
No Matches
Util.hpp
1
2#ifndef GYM_PCB_UTIL_UTIL_H
3#define GYM_PCB_UTIL_UTIL_H
4
5namespace util
6{
7
8bool lexiconumeric_compare(const std::string&, const std::string&);
9
10std::string loadFile(const std::string& filePath);
11
12inline std::string loadFile(const std::string_view filePath) { return loadFile(std::string(filePath)); }
13
14std::string tolower(const std::string&);
15
16bool is1TrueYesOrPlus(const char *);
17
18inline bool is1TrueYesOrPlus(const std::string &s) { return is1TrueYesOrPlus(s.c_str()); }
19
20} // namespace util
21
22#endif // GYM_PCB_UTIL_UTIL_H